@@ -65,8 +65,10 @@ static PanelStockIcon stock_icons [] = {
 	{ PANEL_STOCK_SEARCHTOOL,          "gnome-searchtool" },
 	{ PANEL_STOCK_SCREENSHOT,          "gnome-screenshot" },
 	{ PANEL_STOCK_LOCKSCREEN,          "gnome-lockscreen" },
-	{ PANEL_STOCK_LOGOUT,              "gnome-term-night" },
+	{ PANEL_STOCK_LOGOUT,              "gnome-logout" },
+	{ PANEL_STOCK_FORCE_QUIT,          "panel-force-quit" },
 	{ PANEL_STOCK_GNOME_LOGO,          "gnome-logo-icon-transparent"},
+	{ PANEL_STOCK_MAIN_MENU,           "gnome-main-menu"},
 	{ PANEL_STOCK_DEBIAN,              "gnome-debian"},
 	{ PANEL_STOCK_SUSE,                "gnome-suse"},
 	{ PANEL_STOCK_CDE,                 "cdeappmenu"},
@@ -81,15 +83,10 @@ static PanelStockIcon stock_icons [] = {
 	{ PANEL_STOCK_SLIDING_PANEL,       "gnome-panel-type-sliding" },
 	{ PANEL_STOCK_MENU_PANEL,          "gnome-panel-type-menu" },
 	{ PANEL_STOCK_LAUNCHER,            "launcher-program" },
-	{ PANEL_STOCK_ACTION,		   NULL },
+	{ PANEL_STOCK_ACTION,		   "gnome-other" },
 	{ PANEL_STOCK_DRAWER,              "panel-drawer" },
 	{ PANEL_STOCK_APPLETS,             "gnome-applets" },
 	{ PANEL_STOCK_DESKTOP,             "gnome-ccdesktop" },
-	{ PANEL_STOCK_KDE,                 "go" },
-	{ PANEL_STOCK_ARROW_RIGHT,         "panel-arrow-right" },
-	{ PANEL_STOCK_ARROW_LEFT,          "panel-arrow-left" },
-	{ PANEL_STOCK_ARROW_UP,            "panel-arrow-up" },
-	{ PANEL_STOCK_ARROW_DOWN,          "panel-arrow-down" },
 };
 
 static void
@@ -97,10 +94,7 @@ panel_init_stock_icons (GtkIconFactory *factory)
 {
 	GtkIconSource *source;
 	int            i;
-	int            icon_height = PANEL_DEFAULT_MENU_ICON_SIZE;
 
-	if (!gtk_icon_size_lookup (panel_menu_icon_get_size (), NULL, &icon_height))
-		return;
 
 	source = gtk_icon_source_new ();
 
@@ -111,8 +105,12 @@ panel_init_stock_icons (GtkIconFactory *factory)
 		if (!stock_icons [i].icon)
 			continue;
 
+		/* Look up the icon at an arbitrary large size; if we are
+		 * adding at only one size, we want the largest image
+		 * available
+		 */
 		filename = gnome_desktop_item_find_icon (
-				panel_icon_theme, stock_icons [i].icon, icon_height, 0);
+				panel_icon_theme, stock_icons [i].icon, 1000, 0);
 		if (!filename) {
 			g_warning (_("Unable to load panel stock icon '%s'\n"), stock_icons [i].icon);
 
@@ -143,7 +141,8 @@ typedef struct {
 } PanelStockItem;
 
 static PanelStockItem stock_items [] = {
-	{ PANEL_STOCK_EXECUTE, GTK_STOCK_EXECUTE, N_("_Run") },
+	{ PANEL_STOCK_EXECUTE,    GTK_STOCK_EXECUTE,       N_("_Run") },
+	{ PANEL_STOCK_FORCE_QUIT, PANEL_STOCK_FORCE_QUIT,  N_("_Force quit") },
 };
 
 static void
@@ -189,8 +188,8 @@ panel_init_stock_icons_and_items (void)
 	factory = gtk_icon_factory_new ();
 	gtk_icon_factory_add_default (factory);
 
-	panel_init_stock_items (factory);
 	panel_init_stock_icons (factory);
+	panel_init_stock_items (factory);
 
 	g_object_unref (factory);
 }
